<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Sürüm %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 Özgür Yazılımdır fakat geliştirmesi için önemli miktarda zaman harcanmaktadır.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>%2&apos;nin kesintisiz olarak geliştirilmesine destek olmak için lütfen &lt;a href=&apos;%1&apos;&gt;bağış yapın.&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;GNU Genel Kamu Lisansı&lt;/a&gt; şartları altında dağıtılmaktadır</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>%1 hakkında her zaman bilmek isteyip de soramadıklarınız</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Bunun yanında diğer uygulamalarımı da denemek isteyebilirsiniz:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, bir YouTube uygulaması</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, bir YouTube müzik çalıcısı</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>%1&apos;i, %2 kullanarak kendi dilinize çevirin</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>%1 üzerinde Satın Al</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Devamı</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Devamı</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Geri</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Geri git</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;&apos;e Hoş geldiniz,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1&apos;in müzik koleksiyonunuzu taraması gerekiyor.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>iTunes Koleksiyonu kullan</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>%1 Kullan</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Bir klasör seçin...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1, Last.fm web hizmetine bağlanacak ve sanatçı adlarıyla albüm başlıklarını gönderecek. Böylece albüm kapakları, biyografiler gibi birçok bilgiyi alabilecek.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Eğer bu konuda mahremiyetinizle ilgili endişeleriniz varsa şimdi kapatabilirsiniz.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Müzik koleksiyonunuz nerede?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Müzik koleksiyonunuzun yerini seçin.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Koleksiyonunuzun konumunu bulun</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Bir tarama görevi zaten çalışıyor</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1, müzik koleksiyonunuzu tarıyor.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1, müziklerinizi sınıflandırmak için &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; kullanıyor</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Bu, koleksiyonunuzun boyutuna ve ağ hızınıza bağlı olarak biraz zaman alacak.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Git bir kahve kap</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <source>Please license %1</source>
        <translation>Lütfen %1&apos;i kaydettirin</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Bu deneme sürümünün süresi dolmuş.</translation>
    </message>
    <message>
        <source>This demo will expire in %1 days.</source>
        <translation>Bu deneme sürümünün süresi %1 gün içinde dolacak.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Tam sürümü satın alarak, %1&apos;i oluşturmaya harcadığım emeği de desteklemiş olacaksınız.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Deneme Sürümü Kullan</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Tam sürüme geç</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>Tam sürüm, çalma listesine %1&apos;den fazla parça eklemenize ve müziklerinizi kesintisiz olarak dinlemenize izin verir.</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Çalma listesine eklemek için buraya bırakın</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Sanatçılar</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albümler</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Klasörler</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Oynat/Duraklat</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Geçerli parçadan sonra çalmayı durdur</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Sonraki parça</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Önceki parça</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Sesi yükselt</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Sesi alçalt</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Sessiz</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>İleri sar</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Geri sar</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Geri</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Önceki görünüme git</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Bilgi</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Geçerli parça ile ilgili bilgileri göster</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Ö&amp;nceki</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Bir önceki parçaya geri dön</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Sonraki</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Sonraki parçaya atla</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Oynat</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Çalmaya başla</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Tam Ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Tam ekrana geç</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Kaldır</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Seçilen parçaları çalma listesinden çıkart</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Y&amp;ukarı Taşı</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Seçilen parçaları listede yukarı taşı</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>A&amp;şağı Taşı</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Seçilen parçaları listede aşağı taşı</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Hoşçakalın</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>Koleksiyon klasörünü &amp;değiştir...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Farklı bir müzik koleksiyonu klasörü seçin</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Web Sitesi</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>İnternette %1</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>&amp;Bağışta bulunun</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>%1 ürününün sürekli gelişimine lütfen destek verin</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>%1 hakkında bilgiler</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Temizle</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Tüm parçaları çalma listesinden çıkart</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Rasgele</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Rasgele çalma listesi kipi</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Tekrarla</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Tüm şarkılar çalındıktan sonra tekrar ilk şarkıyı çal</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Sesi kapat</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Uygulama</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Çalma</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>Çalma &amp;Listesi</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Görünüm</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Sesi açmak için %1, kısmak için %2 tuşuna basın</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 açılıyor</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Koleksiyon güncelleniyor...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Koleksiyon güncelleniyor - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Koleksiyon güncellendi</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Ölümcül hata: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Hata: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>&amp;Tam Ekrandan Çık</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Kalan süre: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Ses ayarı: %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Ses kapalı</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Ses açık</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Tam sürüme geç</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 sürüm %2 kullanılabilir durumda.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Daha sonra hatırlat</translation>
    </message>
    <message>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation>Güncellenmiş sürümü edinmek için, e-posta yoluyla aldığınız bağlantı üzerinden %1&apos;i indirin ve yeniden kurun.</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Güncelle</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Pencere</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Simge Durumuna Küçült</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>%1&apos;i Satın Al...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>Bu Parçadan Sonra &amp;Dur</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Öğeleri buraya bırakın</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Çalma listesi bitti</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Bu sadece %1&apos;in bir deneme sürümüdür.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Birkaç parça çalmanıza izin verir, böylece uygulamayı deneyebilir ve işinize yarayıp yaramadığını anlayabilirsiniz.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Devam Et</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Tam sürümü al</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Bu deneme sürümü, çalma listesini %1 parça ile kısıtlar.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Çalma listesi boş</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 parça - Toplam uzunluk: %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>Aramanız sonuç döndürmedi.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Parçalar</translation>
    </message>
</context>
</TS>